#include <TimerOne.h>

const int rel = 15;
const int pir = 5;
const int led = 6;
const int pot = A0;
const int fanpwm = 9;
#define cntdwn_def 100
#define cntdwn_ini 700
#define blcnt_def 3
#define blon 2

int avalue;
int value;
int countdown = 0;
int pirStatus;
int st_on = 0;
int led_on = 0;
int bl_count = 0;



void setup() {
  // put your setup code here, to run once:
  pinMode( rel, OUTPUT );  // Relais Pin
  pinMode( pir, INPUT );   // PIR/Bewegungssensor Input
  pinMode( led, OUTPUT );  // LED output
  pinMode( fanpwm, OUTPUT ); // Fan PWM output
  Serial.begin( 9600 );       
  printf( "Dunstabzug v0.00\n" );
  Timer1.initialize( 1000 );   // Timer 1 is 1000Hz
  digitalWrite( rel, HIGH );   // Relais on
  digitalWrite( led, HIGH );   // led On
  Timer1.pwm( fanpwm, 1023 );  // Full power 
  delay( 1000 );               // Wait a second
  countdown = cntdwn_ini;      // initialize a long on phase to allow PIR to settle 
}

void loop() {
  pirStatus = digitalRead( pir );      // read PIR
  if (pirStatus == HIGH) {             // is active?
    if (countdown < cntdwn_def) {      // only set countdown, when is it less than cntdwn_def to allow the long on phase in the beginning
        countdown = cntdwn_def;
    }
    digitalWrite( led, HIGH );          // switch on LED to indicate PIR motion detected
  }
  else if (st_on == 1) {                // else if fan is running
    digitalWrite( led, LOW );           // switch of LED (to let the LED blink, when fan is not running)
  }
  
  
  if (countdown > 0){                   // count down not elapsed?
      avalue = analogRead( pot );       // read potetiometer
      value = map( avalue, 0, 1023, 500, 1023 );  // calculate fan pwm
      Timer1.pwm( fanpwm, value );      // set fan pwm
      digitalWrite( rel, HIGH );        // switch on relais
      countdown--;                      // count down
      st_on = 1;                        // status is on
  }
  else {                                // count down elapsed
      Timer1.pwm( fanpwm, 0 );          // switch off fan pwm
      st_on = 0;                        // status is off
      digitalWrite( rel, LOW );         // switch off relais
      if (bl_count > 0) {               // blinking periode is blcnt_def
        bl_count--;                     // if > 0 count down
      }
      else {
        bl_count = blcnt_def;           // else restart the blinking periode
      }
      if (bl_count < blon) {            // should the led be on?
        digitalWrite( led, HIGH );      // yes: switch led on
      }
      else {                           
        digitalWrite( led, LOW );       // no: switch led off
      }
  }
  delay( 100 );                         // cycle time of the main loop: approx 100ms
}
